@@ -3,14 +3,15 @@ Overview:
     Functions for directory processing.
 """
 import errno
+import os
 import shutil
 
 __all__ = [
-    'copy',
+    'copy', 'remove',
 ]
 
 
-def copy(src, dst):
+def copy(src: str, dst: str):
     """
     Overview:
         Copy a file or a directory from ``src`` to ``dst``.
@@ -23,9 +24,23 @@ def copy(src, dst):
     :param dst: Destination path.
     """
     try:
-        shutil.copytree(src, dst)
+        shutil.copytree(src, dst)  # copy directory
     except OSError as exc:
         if exc.errno in (errno.ENOTDIR, errno.EINVAL):
-            shutil.copy(src, dst)
+            shutil.copy(src, dst)  # copy file
         else:
             raise  # pragma: no cover
+
+
+def remove(file: str):
+    """
+    Overview:
+        Remove a file or a directory at ``file``.
+        ``file`` can be a file or a directory, both are supported.
+
+    :param file: File or directory to be removed.
+    """
+    try:
+        shutil.rmtree(file)
+    except NotADirectoryError:
+        os.remove(file)
